==> bettertrims-4.0.0%2B1.21.1-fabric-sources.jar: com/bawnorton/bettertrims/client/tooltip/condition/predicate/data/exact/ItemAttributeModifiersExactAdder.java <==
package com.bawnorton.bettertrims.client.tooltip.condition.predicate.data.exact;

import com.bawnorton.bettertrims.client.tooltip.component.CompositeContainerComponent;
import com.bawnorton.bettertrims.client.tooltip.condition.LootConditionTooltips;
import com.bawnorton.bettertrims.client.tooltip.util.Styler;
import org.apache.commons.lang3.StringUtils;

import java.util.List;
import net.minecraft.class_1320;
import net.minecraft.class_1322;
import net.minecraft.class_1799;
import net.minecraft.class_2561;
import net.minecraft.class_310;
import net.minecraft.class_638;
import net.minecraft.class_6880;
import net.minecraft.class_9274;
import net.minecraft.class_9285;
import com.bawnorton.bettertrims.mixin.accessor.ItemStackAccessor;
//?}

public final class ItemAttributeModifiersExactAdder implements ExactAdder<class_9285> {
	@Override
	public void addToBuilder(class_638 level, class_9285 modifiers, LootConditionTooltips.State state, CompositeContainerComponent.Builder builder) {
		List<class_9285.class_9287> entries = modifiers.comp_2393();
		if (entries.isEmpty()) {
			builder.translate(key("attribute_modifiers.any"), Styler::condition);
			return;
		}

		builder.space()
				.translate(key("attribute_modifiers"), Styler::condition)
				.space()
				.cycle(cycleBuilder -> entries.forEach(entry -> {
					CompositeContainerComponent.Builder entryBuilder = CompositeContainerComponent.builder();
					class_6880<class_1320> attribute = entry.comp_2395();
					class_9274 slot = entry.comp_2397();
					class_1322 modifier = entry.comp_2396();
					//? if >=1.21.8 {
					/*ItemAttributeModifiers.Display.attributeModifiers().apply(
					*///?} else {
					((ItemStackAccessor) (Object) class_1799.field_8037).bettertrims$addModifierTooltip(
					 //?}
							component -> entryBuilder.textComponent(component)
									.space()
									.translate(
											key("attribute_modifiers.slot"),
											Styler::condition,
											Styler.name(class_2561.method_43470(StringUtils.capitalize(slot.method_15434())))
									),
							class_310.method_1551().field_1724,
							attribute,
							modifier
					);
					cycleBuilder.component(entryBuilder.build());
				}));
	}
}

==> bettertrims-4.0.2%2B1.21.10-fabric-sources.jar: com/bawnorton/bettertrims/client/tooltip/condition/predicate/data/exact/ItemAttributeModifiersExactAdder.java <==
package com.bawnorton.bettertrims.client.tooltip.condition.predicate.data.exact;

import com.bawnorton.bettertrims.client.tooltip.component.CompositeContainerComponent;
import com.bawnorton.bettertrims.client.tooltip.condition.LootConditionTooltips;
import com.bawnorton.bettertrims.client.tooltip.util.Styler;
import org.apache.commons.lang3.StringUtils;

import java.util.List;
import net.minecraft.class_1320;
import net.minecraft.class_1322;
import net.minecraft.class_2561;
import net.minecraft.class_310;
import net.minecraft.class_638;
import net.minecraft.class_6880;
import net.minecraft.class_9274;
import net.minecraft.class_9285;

//? if <1.21.8 {
/*import net.minecraft.world.item.ItemStack;
import com.bawnorton.bettertrims.mixin.accessor.ItemStackAccessor;
*///?}

public final class ItemAttributeModifiersExactAdder implements ExactAdder<class_9285> {
	@Override
	public void addToBuilder(class_638 level, class_9285 modifiers, LootConditionTooltips.State state, CompositeContainerComponent.Builder builder) {
		List<class_9285.class_9287> entries = modifiers.comp_2393();
		if (entries.isEmpty()) {
			builder.translate(key("attribute_modifiers.any"), Styler::condition);
			return;
		}

		builder.space()
				.translate(key("attribute_modifiers"), Styler::condition)
				.space()
				.cycle(cycleBuilder -> entries.forEach(entry -> {
					CompositeContainerComponent.Builder entryBuilder = CompositeContainerComponent.builder();
					class_6880<class_1320> attribute = entry.comp_2395();
					class_9274 slot = entry.comp_2397();
					class_1322 modifier = entry.comp_2396();
					//? if >=1.21.8 {
					class_9285.class_11193.method_70729().method_70731(
					//?} else {
					/*((ItemStackAccessor) (Object) ItemStack.EMPTY).bettertrims$addModifierTooltip(
					 *///?}
							component -> entryBuilder.textComponent(component)
									.space()
									.translate(
											key("attribute_modifiers.slot"),
											Styler::condition,
											Styler.name(class_2561.method_43470(StringUtils.capitalize(slot.method_15434())))
									),
							class_310.method_1551().field_1724,
							attribute,
							modifier
					);
					cycleBuilder.component(entryBuilder.build());
				}));
	}
}
